from setuptools import setup
setup(name = "TOPSIS_Vrinda_101983029",
      version = "0.2",
      description = "This is an easy to use package for implementing TOPSIS",
      author = 'Vrinda Agarwal',
      packages = ['TOPSIS_Vrinda_101983029'])